Kopf: Kubernetes Operators Framework
====================================

.. toctree::
   :maxdepth: 2
   :caption: First steps:

   install

.. toctree::
   :maxdepth: 2
   :caption: Tutorial:

   concepts
   walkthrough/problem
   walkthrough/prerequisites
   walkthrough/resources
   walkthrough/starting
   walkthrough/creation
   walkthrough/updates
   walkthrough/diffs
   walkthrough/deletion
   walkthrough/cleanup

.. toctree::
   :maxdepth: 2
   :caption: Resource handling:

   handlers
   daemons
   timers
   kwargs
   async
   loading
   resources
   filters
   results
   errors
   scopes
   memos
   indexing

.. toctree::
   :maxdepth: 2
   :caption: Operator handling:

   startup
   shutdown
   probing
   authentication
   configuration
   peering

.. toctree::
   :maxdepth: 2
   :caption: Toolkits:

   events
   hierarchies
   testing
   embedding

.. toctree::
   :maxdepth: 2
   :caption: Recipes:

   deployment
   continuity
   idempotence
   reconciliation
   tips-and-tricks
   troubleshooting

.. toctree::
   :maxdepth: 2
   :caption: Developer Manual:

   minikube
   contributing
   packages/kopf

.. toctree::
   :maxdepth: 2
   :caption: About Kopf:

   vision
   naming
   alternatives


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
